@@ -1,11 +1,11 @@
 """All major API points and command-line tools"""
-import pkg_resources
+from importlib import metadata
 
-from argparse import ArgumentParser
+from argparse import ArgumentParser, ArgumentTypeError
 from lxml import etree
 from xmldiff import diff, formatting, patch
 
-__version__ = pkg_resources.require("xmldiff")[0].version
+__version__ = metadata.version("xmldiff")
 
 FORMATTERS = {
     "diff": formatting.DiffFormatter,
@@ -53,6 +53,19 @@ def diff_files(left, right, diff_options=None, formatter=None):
     )
 
 
+def validate_F(arg):
+    """Type function for argparse - a float within some predefined bounds"""
+    try:
+        F = float(arg)
+    except ValueError:
+        raise ArgumentTypeError("Must be a floating point number")
+    if F <= 0:
+        raise ArgumentTypeError("F can not be zero or lower")
+    if F > 1:
+        raise ArgumentTypeError("F can not be above 1")
+    return F
+
+
 def make_diff_parser():
     parser = ArgumentParser(
         description="Create a diff for two XML files.", add_help=False
@@ -95,7 +108,7 @@ def make_diff_parser():
     )
     parser.add_argument(
         "-F",
-        type=float,
+        type=validate_F,
         help="A value between 0 and 1 that determines how "
         "similar nodes must be to match.",
     )
@@ -115,9 +128,15 @@ def make_diff_parser():
         choices={"accurate", "fast", "faster"},
         help="Choose the node comparison optimization.",
     )
-    parser.add_argument(
+    match_group = parser.add_mutually_exclusive_group()
+    match_group.add_argument(
         "--fast-match", action="store_true", help="A faster, less optimal match run."
     )
+    match_group.add_argument(
+        "--best-match",
+        action="store_true",
+        help="A slower, two-stage match run that may result in smaller diffs. (Experimental)",
+    )
     parser.add_argument(
         "--ignored-attributes",
         type=str,
@@ -161,8 +180,10 @@ def diff_command(args=None):
         "ratio_mode": args.ratio_mode,
         "F": args.F,
         "fast_match": args.fast_match,
+        "best_match": args.best_match,
         "uniqueattrs": _parse_uniqueattrs(args.unique_attributes),
     }
+
     result = diff_files(
         args.file1, args.file2, diff_options=diff_options, formatter=formatter
     )
